#############################################################################
#  Copyright (c) 2012 by Michael Fischer. All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without 
#  modification, are permitted provided that the following conditions 
#  are met:
#  
#  1. Redistributions of source code must retain the above copyright 
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the 
#     documentation and/or other materials provided with the distribution.
#  3. Neither the name of the author nor the names of its contributors may 
#     be used to endorse or promote products derived from this software 
#     without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
#  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
#  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
#  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
#  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
#  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
#  SUCH DAMAGE.
#
#############################################################################
#  History:
#
#  12.02.2012  mifi  First Version, tested with an Altera DE1 board.
#  26.05.2012  mifi  Changed for v2.4.1
#############################################################################

#
# chibios_sw.tcl
#
# A description of the ChibiOS/RT version 2.4.1,
# for use with the Nios II BSP tools
#

# Create a new operating system called "ChibiOS"
create_os ChibiOS_v241

# Set UI display name
set_sw_property display_name "ChibiOS/RT v2.4.1"

# This OS "extends" HAL BSP type
set_sw_property extends_bsp_type HAL

# The version of this software
# Note: this reflects the version of the Altera release that this file
#       shipped in. The ChibiOS/RT version is 2.4.1
set_sw_property version 11.0

# Location in generated BSP that above sources will be copied into
set_sw_property bsp_subdirectory ChibiOS_v241

# Interrupt properties: This OS supports ISR preemption
# (in its interrupt entry/exit code registered with
# macros in alt_hooks.h).
#set_sw_property isr_preemption_supported true
  
#
# Source file listings...
#

# C kernel source files
add_sw_property c_source ChibiOS_v241/kernel/src/chcond.c
add_sw_property c_source ChibiOS_v241/kernel/src/chdebug.c
add_sw_property c_source ChibiOS_v241/kernel/src/chdynamic.c
add_sw_property c_source ChibiOS_v241/kernel/src/chevents.c
add_sw_property c_source ChibiOS_v241/kernel/src/chheap.c
add_sw_property c_source ChibiOS_v241/kernel/src/chlists.c
add_sw_property c_source ChibiOS_v241/kernel/src/chmboxes.c
add_sw_property c_source ChibiOS_v241/kernel/src/chmemcore.c
add_sw_property c_source ChibiOS_v241/kernel/src/chmempools.c
add_sw_property c_source ChibiOS_v241/kernel/src/chmsg.c
add_sw_property c_source ChibiOS_v241/kernel/src/chmtx.c
add_sw_property c_source ChibiOS_v241/kernel/src/chqueues.c
add_sw_property c_source ChibiOS_v241/kernel/src/chregistry.c
add_sw_property c_source ChibiOS_v241/kernel/src/chschd.c
add_sw_property c_source ChibiOS_v241/kernel/src/chsem.c
add_sw_property c_source ChibiOS_v241/kernel/src/chsys.c
add_sw_property c_source ChibiOS_v241/kernel/src/chthreads.c
add_sw_property c_source ChibiOS_v241/kernel/src/chvt.c

# C port source files
add_sw_property c_source ChibiOS_v241/ports/GCC/NiosII/chcore.c
add_sw_property asm_source ChibiOS_v241/ports/GCC/NiosII/chcoreasm.s

# Include kernel files
add_sw_property include_source ChibiOS_v241/kernel/include/ch.h
add_sw_property include_source ChibiOS_v241/kernel/include/chbsem.h
add_sw_property include_source ChibiOS_v241/kernel/include/chcond.h
add_sw_property include_source ChibiOS_v241/kernel/include/chdebug.h
add_sw_property include_source ChibiOS_v241/kernel/include/chdynamic.h
add_sw_property include_source ChibiOS_v241/kernel/include/chevents.h
add_sw_property include_source ChibiOS_v241/kernel/include/chfiles.h
add_sw_property include_source ChibiOS_v241/kernel/include/chheap.h
add_sw_property include_source ChibiOS_v241/kernel/include/chinline.h
add_sw_property include_source ChibiOS_v241/kernel/include/chioch.h
add_sw_property include_source ChibiOS_v241/kernel/include/chlists.h
add_sw_property include_source ChibiOS_v241/kernel/include/chmboxes.h
add_sw_property include_source ChibiOS_v241/kernel/include/chmemcore.h
add_sw_property include_source ChibiOS_v241/kernel/include/chmempools.h
add_sw_property include_source ChibiOS_v241/kernel/include/chmsg.h
add_sw_property include_source ChibiOS_v241/kernel/include/chmtx.h
add_sw_property include_source ChibiOS_v241/kernel/include/chqueues.h
add_sw_property include_source ChibiOS_v241/kernel/include/chregistry.h
add_sw_property include_source ChibiOS_v241/kernel/include/chschd.h
add_sw_property include_source ChibiOS_v241/kernel/include/chsem.h
add_sw_property include_source ChibiOS_v241/kernel/include/chstreams.h
add_sw_property include_source ChibiOS_v241/kernel/include/chsys.h
add_sw_property include_source ChibiOS_v241/kernel/include/chthreads.h
add_sw_property include_source ChibiOS_v241/kernel/include/chvt.h

# Include port files
add_sw_property include_source ChibiOS_v241/ports/GCC/NiosII/chcore.h
add_sw_property include_source ChibiOS_v241/ports/GCC/NiosII/chtypes.h

# Include chconf, os files
add_sw_property include_source ChibiOS_v241/chconf.h
add_sw_property include_source ChibiOS_v241/os/alt_hooks.h

# Overridden HAL files
add_sw_property excluded_hal_source HAL/inc/os/alt_hooks.h

# Include paths
add_sw_property include_directory kernel/include
add_sw_property include_directory ports/GCC/NiosII
add_sw_property include_directory ./

# Makefile additions
add_sw_property alt_cppflags_addition "-D__chibios__"

# Register tcl script for CH_FREQUENCY definition
add_sw_property systemh_generation_script chibios_systemh_generation.tcl

#
# ChibiOS_v241/RT Settings
#

#
# Kernel parameters
#
add_sw_setting decimal_number system_h_define kernel.ch_time_quantum CH_TIME_QUANTUM 20 "Round robin interval"

add_sw_setting decimal_number system_h_define kernel.ch_memcore_size CH_MEMCORE_SIZE 0 "Managed RAM size"

add_sw_setting decimal_number system_h_define kernel.ch_no_idle_thread CH_NO_IDLE_THREAD 0 "Idle thread automatic spawn suppression"

#
# Performance options
#
add_sw_setting boolean system_h_define performance.ch_optimize_speed CH_OPTIMIZE_SPEED 1 "OS optimization"

#
# Subsystem options
#
add_sw_setting boolean system_h_define subsystem.ch_use_registry CH_USE_REGISTRY 1 "Threads registry APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_waitexit CH_USE_WAITEXIT 1 "Threads synchronization APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_semaphores CH_USE_SEMAPHORES 1 "Semaphores APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_semaphores_priority CH_USE_SEMAPHORES_PRIORITY 0 "Semaphores queuing mode"

add_sw_setting boolean system_h_define subsystem.ch_use_semsw CH_USE_SEMSW 1 "Atomic semaphore API"

add_sw_setting boolean system_h_define subsystem.ch_use_mutexes CH_USE_MUTEXES 1 "Mutexes APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_condvars CH_USE_CONDVARS 1 "Conditional Variables APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_condvars_timeout CH_USE_CONDVARS_TIMEOUT 1 "Conditional Variables APIs with timeout"

add_sw_setting boolean system_h_define subsystem.ch_use_events CH_USE_EVENTS 1 "Events Flags APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_events_timeout CH_USE_EVENTS_TIMEOUT 1 "Events Flags APIs with timeout"

add_sw_setting boolean system_h_define subsystem.ch_use_messages CH_USE_MESSAGES 1 "Synchronous Messages APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_messages_priority CH_USE_MESSAGES_PRIORITY 0 "Synchronous Messages queuing mode"

add_sw_setting boolean system_h_define subsystem.ch_use_mailboxes CH_USE_MAILBOXES 1 "Mailboxes APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_queues CH_USE_QUEUES 1 "I/O Queues APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_memcore CH_USE_MEMCORE 1 "Core Memory Manager APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_heap CH_USE_HEAP 1 "Heap Allocator APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_malloc_heap CH_USE_MALLOC_HEAP 0 "C-runtime allocator"

add_sw_setting boolean system_h_define subsystem.ch_use_mempools CH_USE_MEMPOOLS 1 "Memory Pools Allocator APIs"

add_sw_setting boolean system_h_define subsystem.ch_use_dynamic CH_USE_DYNAMIC 1 "Dynamic Threads APIs"

#
# Debug options
#
add_sw_setting boolean system_h_define debug.ch_dbg_system_state_check CH_DBG_SYSTEM_STATE_CHECK 0 "Debug option, system state check"

add_sw_setting boolean system_h_define debug.ch_dbg_enable_checks CH_DBG_ENABLE_CHECKS 0 "Debug option, parameters checks"

add_sw_setting boolean system_h_define debug.ch_dbg_enable_asserts CH_DBG_ENABLE_ASSERTS 0 "Debug option, consistency checks"

add_sw_setting boolean system_h_define debug.ch_dbg_enable_trace CH_DBG_ENABLE_TRACE 0 "Debug option, trace buffer"

add_sw_setting boolean system_h_define debug.ch_dbg_enable_stack_check CH_DBG_ENABLE_STACK_CHECK 0 "Debug option, stack checks"

add_sw_setting boolean system_h_define debug.ch_dbg_fill_threads CH_DBG_FILL_THREADS 0 "Debug option, stacks initialization"

add_sw_setting boolean system_h_define debug.ch_dbg_threads_profiling CH_DBG_THREADS_PROFILING 1 "Debug option, threads profiling"

# End of file
